@@ -21,7 +21,7 @@ This module implements generic functions for subscriptions
 """
 __version__ = "$Revision: 61009 $"
 # $Source$
-# $Id: SubscriptionTool.py 227919 2010-12-01 11:43:20Z glenfant $
+# $Id: SubscriptionTool.py 241646 2011-06-29 16:53:14Z yboussard $
 __docformat__ = 'restructuredtext'
 
 # Python imports
@@ -59,7 +59,8 @@ from Products.ATReferenceBrowserWidget.ATReferenceBrowserWidget import Reference
 
 # import from schema
 from Products.PloneSubscription.content.schemata import FormAddGroupSubscriptionSchema
-
+import logging
+logger = logging.getLogger('Products.SubscriptionTool')
 
 _MARKER = 'Marker'
 
@@ -1080,7 +1081,12 @@ Content-Type: text/plain; charset=%(charset)s
     def sendMail(self, messageText, mto=None, mfrom=None, subject=None, encode=None):
         """Send a preformatted mail"""
         mail_sent=True
-        Log(LOG_DEBUG, "SubscriptionTool.sendMail : mail body\n\n %s" % messageText)
+        
+        if TRACE_SEND_MAIL:
+            logger.info('SubscriptionTool.sendMail '
+                        'message:\n %s ' % (messageText))
+        else:
+            Log(LOG_DEBUG, "SubscriptionTool.sendMail : mail body\n\n %s" % messageText)
         portal = getToolByName(self, 'portal_url').getPortalObject()
         try:
             portal.MailHost.send(messageText, mto, mfrom, subject, encode)
